==> openshift-model-5.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/GroupRestrictionFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class GroupRestrictionFluentImpl<A extends GroupRestrictionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements GroupRestrictionFluent<A> {

    private List<String> groups = new ArrayList<String>();
    private List<LabelSelectorBuilder> labels =  new ArrayList<LabelSelectorBuilder>();

    public GroupRestrictionFluentImpl() {
    }

    public GroupRestrictionFluentImpl(GroupRestriction instance) {
        this.withGroups(instance.getGroups()); 
        this.withLabels(instance.getLabels()); 
    }

    public A addToGroups(int index,String item) {
        if (this.groups == null) {this.groups = new ArrayList<String>();}
        this.groups.add(index, item);
        return (A)this;
    }

    public A setToGroups(int index,String item) {
        if (this.groups == null) {this.groups = new ArrayList<String>();}
        this.groups.set(index, item); return (A)this;
    }

    public A addToGroups(String... items) {
        if (this.groups == null) {this.groups = new ArrayList<String>();}
        for (String item : items) {this.groups.add(item);} return (A)this;
    }

    public A addAllToGroups(Collection<String> items) {
        if (this.groups == null) {this.groups = new ArrayList<String>();}
        for (String item : items) {this.groups.add(item);} return (A)this;
    }

    public A removeFromGroups(String... items) {
        for (String item : items) {if (this.groups!= null){ this.groups.remove(item);}} return (A)this;
    }

    public A removeAllFromGroups(Collection<String> items) {
        for (String item : items) {if (this.groups!= null){ this.groups.remove(item);}} return (A)this;
    }

    public List<String> getGroups() {
        return this.groups;
    }

    public String getGroup(int index) {
        return this.groups.get(index);
    }

    public String getFirstGroup() {
        return this.groups.get(0);
    }

    public String getLastGroup() {
        return this.groups.get(groups.size() - 1);
    }

    public String getMatchingGroup(Predicate<String> predicate) {
        for (String item: groups) { if(predicate.test(item)){ return item;} } return null;
    }

    public Boolean hasMatchingGroup(Predicate<String> predicate) {
        for (String item: groups) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withGroups(List<String> groups) {
        if (this.groups != null) { _visitables.get("groups").removeAll(this.groups);}
        if (groups != null) {this.groups = new ArrayList<String>(); for (String item : groups){this.addToGroups(item);}} else { this.groups = null;} return (A) this;
    }

    public A withGroups(String... groups) {
        if (this.groups != null) {this.groups.clear();}
        if (groups != null) {for (String item :groups){ this.addToGroups(item);}} return (A) this;
    }

    public Boolean hasGroups() {
        return groups != null && !groups.isEmpty();
    }

    public A addNewGroup(String arg1) {
        return (A)addToGroups(new String(arg1));
    }

    public A addNewGroup(StringBuilder arg1) {
        return (A)addToGroups(new String(arg1));
    }

    public A addNewGroup(StringBuffer arg1) {
        return (A)addToGroups(new String(arg1));
    }

    public A addToLabels(int index,LabelSelector item) {
        if (this.labels == null) {this.labels = new ArrayList<LabelSelectorBuilder>();}
        LabelSelectorBuilder builder = new LabelSelectorBuilder(item);_visitables.get("labels").add(index >= 0 ? index : _visitables.get("labels").size(), builder);this.labels.add(index >= 0 ? index : labels.size(), builder); return (A)this;
    }

    public A setToLabels(int index,LabelSelector item) {
        if (this.labels == null) {this.labels = new ArrayList<LabelSelectorBuilder>();}
        LabelSelectorBuilder builder = new LabelSelectorBuilder(item);
        if (index < 0 || index >= _visitables.get("labels").size()) { _visitables.get("labels").add(builder); } else { _visitables.get("labels").set(index, builder);}
        if (index < 0 || index >= labels.size()) { labels.add(builder); } else { labels.set(index, builder);}
         return (A)this;
    }

    public A addToLabels(LabelSelector... items) {
        if (this.labels == null) {this.labels = new ArrayList<LabelSelectorBuilder>();}
        for (LabelSelector item : items) {LabelSelectorBuilder builder = new LabelSelectorBuilder(item);_visitables.get("labels").add(builder);this.labels.add(builder);} return (A)this;
    }

    public A addAllToLabels(Collection<LabelSelector> items) {
        if (this.labels == null) {this.labels = new ArrayList<LabelSelectorBuilder>();}
        for (LabelSelector item : items) {LabelSelectorBuilder builder = new LabelSelectorBuilder(item);_visitables.get("labels").add(builder);this.labels.add(builder);} return (A)this;
    }

    public A removeFromLabels(LabelSelector... items) {
        for (LabelSelector item : items) {LabelSelectorBuilder builder = new LabelSelectorBuilder(item);_visitables.get("labels").remove(builder);if (this.labels != null) {this.labels.remove(builder);}} return (A)this;
    }

    public A removeAllFromLabels(Collection<LabelSelector> items) {
        for (LabelSelector item : items) {LabelSelectorBuilder builder = new LabelSelectorBuilder(item);_visitables.get("labels").remove(builder);if (this.labels != null) {this.labels.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromLabels(Predicate<LabelSelectorBuilder> predicate) {
        if (labels == null) return (A) this;
        final Iterator<LabelSelectorBuilder> each = labels.iterator();
        final List visitables = _visitables.get("labels");
        while (each.hasNext()) {
          LabelSelectorBuilder builder = each.next();
          if (predicate.test(builder)) {
            visitables.remove(builder);
            each.remove();
          }
        }
        return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildLabels instead.
 * @return The buildable object.
 */
@Deprecated public List<LabelSelector> getLabels() {
        return build(labels);
    }

    public List<LabelSelector> buildLabels() {
        return build(labels);
    }

    public LabelSelector buildLabel(int index) {
        return this.labels.get(index).build();
    }

    public LabelSelector buildFirstLabel() {
        return this.labels.get(0).build();
    }

    public LabelSelector buildLastLabel() {
        return this.labels.get(labels.size() - 1).build();
    }

    public LabelSelector buildMatchingLabel(Predicate<LabelSelectorBuilder> predicate) {
        for (LabelSelectorBuilder item: labels) { if(predicate.test(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingLabel(Predicate<LabelSelectorBuilder> predicate) {
        for (LabelSelectorBuilder item: labels) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withLabels(List<LabelSelector> labels) {
        if (this.labels != null) { _visitables.get("labels").removeAll(this.labels);}
        if (labels != null) {this.labels = new ArrayList<LabelSelectorBuilder>(); for (LabelSelector item : labels){this.addToLabels(item);}} else { this.labels = null;} return (A) this;
    }

    public A withLabels(LabelSelector... labels) {
        if (this.labels != null) {this.labels.clear();}
        if (labels != null) {for (LabelSelector item :labels){ this.addToLabels(item);}} return (A) this;
    }

    public Boolean hasLabels() {
        return labels != null && !labels.isEmpty();
    }

    public GroupRestrictionFluent.LabelsNested<A> addNewLabel() {
        return new LabelsNestedImpl();
    }

    public GroupRestrictionFluent.LabelsNested<A> addNewLabelLike(LabelSelector item) {
        return new LabelsNestedImpl(-1, item);
    }

    public GroupRestrictionFluent.LabelsNested<A> setNewLabelLike(int index,LabelSelector item) {
        return new LabelsNestedImpl(index, item);
    }

    public GroupRestrictionFluent.LabelsNested<A> editLabel(int index) {
        if (labels.size() <= index) throw new RuntimeException("Can't edit labels. Index exceeds size.");
        return setNewLabelLike(index, buildLabel(index));
    }

    public GroupRestrictionFluent.LabelsNested<A> editFirstLabel() {
        if (labels.size() == 0) throw new RuntimeException("Can't edit first labels. The list is empty.");
        return setNewLabelLike(0, buildLabel(0));
    }

    public GroupRestrictionFluent.LabelsNested<A> editLastLabel() {
        int index = labels.size() - 1;
        if (index < 0) throw new RuntimeException("Can't edit last labels. The list is empty.");
        return setNewLabelLike(index, buildLabel(index));
    }

    public GroupRestrictionFluent.LabelsNested<A> editMatchingLabel(Predicate<LabelSelectorBuilder> predicate) {
        int index = -1;
        for (int i=0;i<labels.size();i++) { 
        if (predicate.test(labels.get(i))) {index = i; break;}
        } 
        if (index < 0) throw new RuntimeException("Can't edit matching labels. No match found.");
        return setNewLabelLike(index, buildLabel(index));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        GroupRestrictionFluentImpl that = (GroupRestrictionFluentImpl) o;
        if (groups != null ? !groups.equals(that.groups) :that.groups != null) return false;
        if (labels != null ? !labels.equals(that.labels) :that.labels != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(groups,  labels,  super.hashCode());
    }

    public class LabelsNestedImpl<N> extends LabelSelectorFluentImpl<GroupRestrictionFluent.LabelsNested<N>> implements GroupRestrictionFluent.LabelsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final LabelSelectorBuilder builder;
        private final int index;

            LabelsNestedImpl(int index,LabelSelector item) {
                this.index = index;
                this.builder = new LabelSelectorBuilder(this, item);
                        
            }

            LabelsNestedImpl() {
                this.index = -1;
                this.builder = new LabelSelectorBuilder(this);
                        
            }

            public N and() {
                return (N) GroupRestrictionFluentImpl.this.setToLabels(index,builder.build());
            }

            public N endLabel() {
                return and();
            }
    }


}

==> openshift-model-5.3.2-sources.jar: annotations/io/fabric8/openshift/api/model/GroupRestrictionFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class GroupRestrictionFluentImpl<A extends GroupRestrictionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements GroupRestrictionFluent<A> {

    private List<String> groups = new ArrayList<String>();
    private List<LabelSelectorBuilder> labels =  new ArrayList<LabelSelectorBuilder>();

    public GroupRestrictionFluentImpl() {
    }

    public GroupRestrictionFluentImpl(GroupRestriction instance) {
        this.withGroups(instance.getGroups()); 
        this.withLabels(instance.getLabels()); 
    }

    public A addToGroups(int index,String item) {
        if (this.groups == null) {this.groups = new ArrayList<String>();}
        this.groups.add(index, item);
        return (A)this;
    }

    public A setToGroups(int index,String item) {
        if (this.groups == null) {this.groups = new ArrayList<String>();}
        this.groups.set(index, item); return (A)this;
    }

    public A addToGroups(String... items) {
        if (this.groups == null) {this.groups = new ArrayList<String>();}
        for (String item : items) {this.groups.add(item);} return (A)this;
    }

    public A addAllToGroups(Collection<String> items) {
        if (this.groups == null) {this.groups = new ArrayList<String>();}
        for (String item : items) {this.groups.add(item);} return (A)this;
    }

    public A removeFromGroups(String... items) {
        for (String item : items) {if (this.groups!= null){ this.groups.remove(item);}} return (A)this;
    }

    public A removeAllFromGroups(Collection<String> items) {
        for (String item : items) {if (this.groups!= null){ this.groups.remove(item);}} return (A)this;
    }

    public List<String> getGroups() {
        return this.groups;
    }

    public String getGroup(int index) {
        return this.groups.get(index);
    }

    public String getFirstGroup() {
        return this.groups.get(0);
    }

    public String getLastGroup() {
        return this.groups.get(groups.size() - 1);
    }

    public String getMatchingGroup(Predicate<String> predicate) {
        for (String item: groups) { if(predicate.test(item)){ return item;} } return null;
    }

    public Boolean hasMatchingGroup(Predicate<String> predicate) {
        for (String item: groups) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withGroups(List<String> groups) {
        if (this.groups != null) { _visitables.get("groups").removeAll(this.groups);}
        if (groups != null) {this.groups = new ArrayList<String>(); for (String item : groups){this.addToGroups(item);}} else { this.groups = null;} return (A) this;
    }

    public A withGroups(String... groups) {
        if (this.groups != null) {this.groups.clear();}
        if (groups != null) {for (String item :groups){ this.addToGroups(item);}} return (A) this;
    }

    public Boolean hasGroups() {
        return groups != null && !groups.isEmpty();
    }

    public A addNewGroup(StringBuilder arg1) {
        return (A)addToGroups(new String(arg1));
    }

    public A addNewGroup(int[] arg1,int arg2,int arg3) {
        return (A)addToGroups(new String(arg1, arg2, arg3));
    }

    public A addNewGroup(char[] arg1) {
        return (A)addToGroups(new String(arg1));
    }

    public A addNewGroup(StringBuffer arg1) {
        return (A)addToGroups(new String(arg1));
    }

    public A addNewGroup(byte[] arg1,int arg2) {
        return (A)addToGroups(new String(arg1, arg2));
    }

    public A addNewGroup(byte[] arg1) {
        return (A)addToGroups(new String(arg1));
    }

    public A addNewGroup(char[] arg1,int arg2,int arg3) {
        return (A)addToGroups(new String(arg1, arg2, arg3));
    }

    public A addNewGroup(byte[] arg1,int arg2,int arg3) {
        return (A)addToGroups(new String(arg1, arg2, arg3));
    }

    public A addNewGroup(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)addToGroups(new String(arg1, arg2, arg3, arg4));
    }

    public A addNewGroup(String arg1) {
        return (A)addToGroups(new String(arg1));
    }

    public A addToLabels(int index,LabelSelector item) {
        if (this.labels == null) {this.labels = new ArrayList<LabelSelectorBuilder>();}
        LabelSelectorBuilder builder = new LabelSelectorBuilder(item);_visitables.get("labels").add(index >= 0 ? index : _visitables.get("labels").size(), builder);this.labels.add(index >= 0 ? index : labels.size(), builder); return (A)this;
    }

    public A setToLabels(int index,LabelSelector item) {
        if (this.labels == null) {this.labels = new ArrayList<LabelSelectorBuilder>();}
        LabelSelectorBuilder builder = new LabelSelectorBuilder(item);
        if (index < 0 || index >= _visitables.get("labels").size()) { _visitables.get("labels").add(builder); } else { _visitables.get("labels").set(index, builder);}
        if (index < 0 || index >= labels.size()) { labels.add(builder); } else { labels.set(index, builder);}
         return (A)this;
    }

    public A addToLabels(LabelSelector... items) {
        if (this.labels == null) {this.labels = new ArrayList<LabelSelectorBuilder>();}
        for (LabelSelector item : items) {LabelSelectorBuilder builder = new LabelSelectorBuilder(item);_visitables.get("labels").add(builder);this.labels.add(builder);} return (A)this;
    }

    public A addAllToLabels(Collection<LabelSelector> items) {
        if (this.labels == null) {this.labels = new ArrayList<LabelSelectorBuilder>();}
        for (LabelSelector item : items) {LabelSelectorBuilder builder = new LabelSelectorBuilder(item);_visitables.get("labels").add(builder);this.labels.add(builder);} return (A)this;
    }

    public A removeFromLabels(LabelSelector... items) {
        for (LabelSelector item : items) {LabelSelectorBuilder builder = new LabelSelectorBuilder(item);_visitables.get("labels").remove(builder);if (this.labels != null) {this.labels.remove(builder);}} return (A)this;
    }

    public A removeAllFromLabels(Collection<LabelSelector> items) {
        for (LabelSelector item : items) {LabelSelectorBuilder builder = new LabelSelectorBuilder(item);_visitables.get("labels").remove(builder);if (this.labels != null) {this.labels.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromLabels(Predicate<LabelSelectorBuilder> predicate) {
        if (labels == null) return (A) this;
        final Iterator<LabelSelectorBuilder> each = labels.iterator();
        final List visitables = _visitables.get("labels");
        while (each.hasNext()) {
          LabelSelectorBuilder builder = each.next();
          if (predicate.test(builder)) {
            visitables.remove(builder);
            each.remove();
          }
        }
        return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildLabels instead.
 * @return The buildable object.
 */
@Deprecated public List<LabelSelector> getLabels() {
        return build(labels);
    }

    public List<LabelSelector> buildLabels() {
        return build(labels);
    }

    public LabelSelector buildLabel(int index) {
        return this.labels.get(index).build();
    }

    public LabelSelector buildFirstLabel() {
        return this.labels.get(0).build();
    }

    public LabelSelector buildLastLabel() {
        return this.labels.get(labels.size() - 1).build();
    }

    public LabelSelector buildMatchingLabel(Predicate<LabelSelectorBuilder> predicate) {
        for (LabelSelectorBuilder item: labels) { if(predicate.test(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingLabel(Predicate<LabelSelectorBuilder> predicate) {
        for (LabelSelectorBuilder item: labels) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withLabels(List<LabelSelector> labels) {
        if (this.labels != null) { _visitables.get("labels").removeAll(this.labels);}
        if (labels != null) {this.labels = new ArrayList<LabelSelectorBuilder>(); for (LabelSelector item : labels){this.addToLabels(item);}} else { this.labels = null;} return (A) this;
    }

    public A withLabels(LabelSelector... labels) {
        if (this.labels != null) {this.labels.clear();}
        if (labels != null) {for (LabelSelector item :labels){ this.addToLabels(item);}} return (A) this;
    }

    public Boolean hasLabels() {
        return labels != null && !labels.isEmpty();
    }

    public io.fabric8.openshift.api.model.GroupRestrictionFluent.LabelsNested<A> addNewLabel() {
        return new LabelsNestedImpl();
    }

    public io.fabric8.openshift.api.model.GroupRestrictionFluent.LabelsNested<A> addNewLabelLike(LabelSelector item) {
        return new LabelsNestedImpl(-1, item);
    }

    public io.fabric8.openshift.api.model.GroupRestrictionFluent.LabelsNested<A> setNewLabelLike(int index,LabelSelector item) {
        return new LabelsNestedImpl(index, item);
    }

    public io.fabric8.openshift.api.model.GroupRestrictionFluent.LabelsNested<A> editLabel(int index) {
        if (labels.size() <= index) throw new RuntimeException("Can't edit labels. Index exceeds size.");
        return setNewLabelLike(index, buildLabel(index));
    }

    public io.fabric8.openshift.api.model.GroupRestrictionFluent.LabelsNested<A> editFirstLabel() {
        if (labels.size() == 0) throw new RuntimeException("Can't edit first labels. The list is empty.");
        return setNewLabelLike(0, buildLabel(0));
    }

    public io.fabric8.openshift.api.model.GroupRestrictionFluent.LabelsNested<A> editLastLabel() {
        int index = labels.size() - 1;
        if (index < 0) throw new RuntimeException("Can't edit last labels. The list is empty.");
        return setNewLabelLike(index, buildLabel(index));
    }

    public io.fabric8.openshift.api.model.GroupRestrictionFluent.LabelsNested<A> editMatchingLabel(Predicate<LabelSelectorBuilder> predicate) {
        int index = -1;
        for (int i=0;i<labels.size();i++) { 
        if (predicate.test(labels.get(i))) {index = i; break;}
        } 
        if (index < 0) throw new RuntimeException("Can't edit matching labels. No match found.");
        return setNewLabelLike(index, buildLabel(index));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        GroupRestrictionFluentImpl that = (GroupRestrictionFluentImpl) o;
        if (groups != null ? !groups.equals(that.groups) :that.groups != null) return false;
        if (labels != null ? !labels.equals(that.labels) :that.labels != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(groups,  labels,  super.hashCode());
    }

    public class LabelsNestedImpl<N> extends LabelSelectorFluentImpl<io.fabric8.openshift.api.model.GroupRestrictionFluent.LabelsNested<N>> implements io.fabric8.openshift.api.model.GroupRestrictionFluent.LabelsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final LabelSelectorBuilder builder;
        private final int index;

            LabelsNestedImpl(int index,LabelSelector item) {
                this.index = index;
                this.builder = new LabelSelectorBuilder(this, item);
                        
            }

            LabelsNestedImpl() {
                this.index = -1;
                this.builder = new LabelSelectorBuilder(this);
                        
            }

            public N and() {
                return (N) GroupRestrictionFluentImpl.this.setToLabels(index,builder.build());
            }

            public N endLabel() {
                return and();
            }
    }


}
